# rsconnect

<!-- badges: start -->
[![lifecycle:
experimental](https://img.shields.io/badge/lifecycle-experimental-orange.svg)](https://lifecycle.r-lib.org/articles/stages.html)
<!-- badges: end -->


A simple meta-package to install packages for working with RStudio Connect.

The packages installed with this package are:

* [rsconnect-jupyter](https://pypi.org/project/rsconnect-jupyter/)
* [rsconnect-python](https://pypi.org/project/rsconnect-python/)
* [pins](https://pypi.org/project/pins/)

## License

This package is released under an MIT license.

This project is **not** affiliated with RStudio.

"RStudio" and "RStudio Connect" are trademarks of [RStudio, PBC](https://rstudio.com).

